!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!calcTotalOceanLutRefl!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!simple driver to calculate total top of the atmosphere reflectance for water&ice  clouds over ocean
!It calculates C6 (MS + SS) reflectance for any combination of angles over the the LUT angular 
!space (33 solar, 28 view, 37 azim)
!
!MODULES USED
!   calc_subs_m
!PROCEDURES CALLED:
!FUNCTIONS:
!         NONE
!!SUBROUTINES:
!   SUBROUTINE calcReflOcean                    !Calls to calculate Ocean Rflectance (Ice or Liq)
!   calcReflOcean(solarang,viewang,azmang,windspeed,lut_wspeed,phaseFileName,oceanWaterLUTName,'LIQUID',totRW)
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!



PROGRAM calcTotalOceanLutRefl
USE calc_subs_m

IMPLICIT NONE


INTEGER, PARAMETER:: numOfSolarAngs = 33, numOfViewAngs = 28, nphi=37   !LUT angular space 
REAL::solarmu(1:numOfSolarAngs),viewmu(1:numOfViewAngs),deltaphi=5.0,phi(1:nphi)
REAL::solarangvec(1:numOfSolarAngs),viewangvec(1:numOfViewAngs)
!REAL::totoutrefl(1:18,1:7,1:34,1:NPHI,1:numOfSolarAngs,1:numOfViewAngs)  !!!!output reflectance. 


CHARACTER(len = 400)::phaseFileName,samplename, lutDir
CHARACTER(len = 600)::outname
CHARACTER(len = 400), DIMENSION(3)::oceanWaterLUTName, oceanIceLUTName

REAL::solarang,viewang,azmang,windspeed,surfAlb,lut_wspeed(3),angs(3)
 
TYPE(outRefl)::totRW,totRI       !!reflectanc(:,:,:) = totR%totalRefl(:,:,:), DIM1=nre, DIM2=nwl, DIM3=ntau
                          !output from the reader

INTEGER::hdf_id, retstat,i,ia,is,iv,iw,iag,fag

REAL::totoutrefl(1:numOfViewAngs,1:numOfSolarAngs,1:NPHI,1:34,1:7,1:18)
REAL::totoutrefl0(1:numOfViewAngs,1:numOfSolarAngs,1:NPHI,1:34,1:7,1:18),temprefl(18,34)

CHARACTER(11)  :: whatdate
CHARACTER(8)   :: whattime
CHARACTER(13)::dateTimeString



	CALL getdateAndTime(whatdate, whattime,dateTimeString)


   NULLIFY(totRW%totalRefl,totRW%lutRE,totRW%lutTau,totRW%lutWvl)   
   NULLIFY(totRI%totalRefl,totRI%lutRE,totRI%lutTau,totRI%lutWvl)


!!path to where the library folder "MODIS_C6_LUTS" is located;    
         lutDir = '/Users/nandana/MODIS_ACOL_LUTS/'



!!!!!! LUT Angular parameter values, solar zenith, sensor zenith, and relative azimuth!!!!!!!!!!!!!!
    solarmu(1:13)   = (/ (0.05 * i+0.15, i=0,12) /) !numOfSolarAngs = 33, numOfViewAngs = 28
    viewmu(1:8)     = (/(0.05 * i + 0.40,i=0,7) /)
    solarmu(14:numOfSolarAngs)   = (/ (0.0125 * i+0.7625, i=0,19) /) 
    viewmu(9:numOfViewAngs)     = (/(0.0125 * i + 0.7625,i=0,19) /)
    phi(1:NPHI)= (/ (deltaphi * i,i=0,NPHI-1)/) 
    solarangvec 	= acos(solarmu*1.d0) * 180.0/acos(-1.d0 )
    viewangvec     = acos(viewmu*1.d0)*180.0/acos(-1.d0 )

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


    print '(1X,A)', 'Given below are the 37 azimuth, 33 solar, and 28 view angles for LUTs'
    print '(1X,A)', 'Pick/choose the angular geometry from these angles'
    print '(A)','  '
    print '(1x,A,3x,A,6x,A,6x,A)', 'index','azimuth', 'solar','view'
    
    do i = 1, nphi 
        if(i < 29) print'(i4, 6x, f4.0, 8x, f5.2, 6x, f5.2)', i, phi(i), solarangvec(i), viewangvec(i)
        if(i >=29 .and. i < 34)print '(i4, 6x, f4.0, 8x, f5.2)', i, phi(i), solarangvec(i)
        if(i >= 34)print '(i4, 6x, f4.0)',i, phi(i)
   enddo 
   print '(A)','  '

    print '(1X,A)','Pick the indices of the angle combination to run.' 
    print '(1X,A)','(Example output was created with all angles = 60, i.e., iazm=13, isol=8, iview=3 & wspeed=6.0 m/s)'
    write(*,'(a)',advance='NO')' Enter index for the rel azimuth: '
    read(*,'(I2)')ia
    azmang=phi(ia)
    print '(a,f6.2,a)','Relative Azimuth = ',azmang,' degrees'
    write(*,'(a)',advance='NO')' Enter index for the solar zenith: '
    read(*,'(I2)')is
    solarang = solarangvec(is)
    print '(a,f5.2,a)','Solar Zenith = ',solarang,' degrees'

    write(*,'(a)',advance='NO')' Enter index for the zensor zenith: '
    read(*,'(I2)')iv
    viewang = viewangvec(iv)
    print '(a,f5.2,a)','Sensor Zenith/View = ',viewang,' degrees'

    write(*,'(a)',advance='NO')' Now enter a value for the wind speed, u (m/s), 3.0 =< u <= 15.0: '
    read(*,*)windspeed
    print'(1X,A)','(Note that no wind direction input, since LUTs are a result of averaging LUTs with directions 0, 90, 180, and 270 degrees)'

    iag = floor(windspeed)
    fag = 100*(windspeed - iag)
    
        !!!!!!!!!!!!!!!!!!!!!input data for which total R calculated!!!!
!    windspeed = 6.0
!    solarang 	= 30.0     !index =8 in the solarmuarray
!    viewang		= 30.0	   !index =3 in the viewmuarray
!    azmang 		= 30.0	   !index = 13 in the azm angarray


    angs=(/solarang, viewang, azmang/)

    
!!!!!!! LAMB WATER LUT and Phase LUT Information!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    
        
    phaseFileName      = trim(lutDir)//'MODIS_C6_LUTS/modis_water/IceAndWaterPhaseFunctionData_2013.hdf'

	oceanIceLUTName(1)      = trim(lutDir)//'MODIS_C6_LUTS/modis_ice/ocean_multi_reflectance_ice_library_wspeed_3_mean.hdf'
	oceanIceLUTName(2)      = trim(lutDir)//'MODIS_C6_LUTS/modis_ice/ocean_multi_reflectance_ice_library_wspeed_7_mean.hdf'
	oceanIceLUTName(3)      = trim(lutDir)//'MODIS_C6_LUTS/modis_ice/ocean_multi_reflectance_ice_library_wspeed_15_mean.hdf'
	
	oceanWaterLUTName(1)      = trim(lutDir)//'MODIS_C6_LUTS/modis_water/ocean_multi_reflectance_water_library_wspeed_3_mean.hdf'
    oceanWaterLUTName(2)      = trim(lutDir)//'MODIS_C6_LUTS/modis_water/ocean_multi_reflectance_water_library_wspeed_7_mean.hdf'
    oceanWaterLUTName(3)      = trim(lutDir)//'MODIS_C6_LUTS/modis_water/ocean_multi_reflectance_water_library_wspeed_15_mean.hdf'
    

    lut_wspeed=(/ 3.0, 7.0, 15.0/)

!!!!!!! END LUT Information!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    
    

   
!!!!!!!!!!output file name !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   
    write(outName,'(a,a,i2.2,a,i2.2,a,i2.2,a,i2.2,a,i2.2,a,a,a)')trim(lutDir),'MODIS_C6_LUTS/OUTPUT/ocean_F90_C6_reflectance_sol_',is,'_view_',iv,'_relazm_',ia,&
          '_wspeed_',iag,'pt',fag,'_',dateTimeString,'.hdf'
    print*,trim(outName)

!!!!!!!!!!!!!!!!!!Ocean Reflectances : Water !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
            
	 			
          CALL calcReflOcean(solarang,viewang,azmang,windspeed,lut_wspeed,phaseFileName,oceanWaterLUTName,'LIQUID',totRW)
          
!!!!!!!!!!!!!!!!!!Ocean Reflectances : ICE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

           CALL calcReflOcean(solarang,viewang,azmang,windspeed,lut_wspeed,phaseFileName,oceanIceLUTName,'ICE',totRI)


    CALL createHDFFile(trim(outName),totRW%totalRefl, totRI%totalRefl,angs, totRW%lutRE,totRI%lutRE,totRI%lutTau, totRI%lutWvl, WSPEED=windspeed)
	 			
            
     
   
                      

END PROGRAM calcTotalOceanLutRefl



