!----------------------------------MUDULE calc_subs_m-----------------------------------------------
!****FOR LUTS FLIPPED, with derived types*********
!Fortran 90 module that contains caller routines to compute the total reflectance from C6 LUTs.
!No Vector/Array inputs are allowed except for the lut array names for ocean rflectance calculations
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!MODULES USED
!   nterpolate_C6_LUT_m.f90
!PROCEDURES INCLUDED:
!FUNCTIONS:
!         NONE
!!SUBROUTINES:
!   SUBROUTINE calcLambRefl                     !Calls to calculate Lamb Rflectance (Ice or Liq)
!   SUBROUTINE calcReflOcean                    !Calls to calc Ocean Reflectance (Ice or Liq)
!No Vector/Array inputs are allowed except for the lut array names for ocean rflectance calculations
!PROGRAMMER:
!
!             Nandana Amarasinghe (SSAI)
!             Climate and Radiation Branch
!             NASA Goddard Space Flight Center
!             Greenbelt, Maryland 20771, U.S.A.
!             nandana.amarasinghe@ssaihq.com or nandana.d.amarasinghe@nasa.gov
!
!---------------------------------------------------------------------------------------------------

MODULE calc_subs_m
USE interpolate_C6_LUT_m
IMPLICIT NONE

TYPE outRefl
    REAL, DIMENSION(:,:,:), POINTER::totalRefl
    REAL, DIMENSION(:), POINTER::lutRE
    REAL, DIMENSION(:), POINTER::lutTau
    REAL, DIMENSION(:), POINTER::lutWvl
    INTEGER, DIMENSION(3)::totalReflDims
END TYPE

INTEGER,PARAMETER::NUM_WIND_SPEEDS = 3



CONTAINS

SUBROUTINE calcLambRefl(solarang,viewang,azmang,surfAlbedo,phaseName,lambLutName,phase, reflOut)

IMPLICIT NONE
!simple driver program calculate full reflectance
CHARACTER(len=*),INTENT(IN)::phaseName, phase
CHARACTER(len=*),INTENT(IN)::lambLutName
REAL, INTENT(IN)::solarang,viewang,azmang,surfAlbedo
TYPE(outRefl), INTENT(INOUT)::reflOut


TYPE(pfData), SAVE::testpf
TYPE(lutFlux) ::testFlux
type(lutSSP) :: testSSP
TYPE(lutRefl) ::testLambPtr
LOGICAL, SAVE:: firstPass=.TRUE.
CHARACTER(10), SAVE::phaseSaved='JUNK'
INTEGER::nre, nwl, ntau,ierror


IF(firstPass)THEN
!    print*,'comes here1',solarang,viewang,azmang

  CALL nullifyPointers(thisPf = testpf)
  CALL pfdata_read(testpf,trim(phaseName)) 
  firstPass = .FALSE.
  phaseSaved = trim(phase)
ENDIF

!		    print*,'just beforer calling main sub',associated(testLambPtr%msr),associated(testLambPtr%solzen),associated(testLambPtr%senzen),associated(testLambPtr%relazm)
!		    print*,associated(testSSP%re),associated(testSSP%cot),associated(testSSP%pfconst),associated(testSSP%truncf), &
!		           associated(testSSP%ssalb), associated(testSSP%QE)
!
!
!    print*,'comes here2',solarang,viewang,azmang

    CALL nullifyPointers(thisRefl=testLambPtr,thisSSP=testSSP,thisFlux=testFlux)
      
    CALL refl_read(trim(lambLutName),solarang,viewang,azmang,ierror,thisMSR=testLambPtr,thisFlux=testFlux,thisSSP=testSSP)

   
	ntau = size(testSSP%cot); nwl = size(testSSP%ssalb,1); nre = size(testSSP%ssalb,2)
	
    IF(ASSOCIATED(reflOut%totalRefl))DEALLOCATE(reflOut%totalRefl)
	allocate(reflOut%totalRefl(ntau,nwl,nre))
	reflOut%totalReflDims = (/ntau, nwl, nre/)
	
	IF(ASSOCIATED(reflOut%lutRE))DEALLOCATE(reflOut%lutRE)
	allocate(reflOut%lutRE(nre))
	reflOut%lutRE(:) = testSSP%re
	
	IF(ASSOCIATED(reflOut%lutTau))DEALLOCATE(reflOut%lutTau)
	allocate(reflOut%lutTau(ntau))
	reflOut%lutTau(:) = testSSP%cot
	
	IF(ASSOCIATED(reflOut%lutWvl))DEALLOCATE(reflOut%lutWvl)
	allocate(reflOut%lutWvl(nwl))

	reflOut%lutWvl(:) = testSSP%wvl

	

  CALL GetReflForGivenSurfAlbedoNew(testpf, testSSP,testLambPtr,testFlux,solarang,viewang,azmang,surfAlbedo,phase,reflOut%totalRefl,ierror)
  
!		    print*,'just after calling main sub',associated(testLambPtr%msr),associated(testLambPtr%solzen),associated(testLambPtr%senzen),associated(testLambPtr%relazm)
!		    print*,associated(testSSP%re),associated(testSSP%cot),associated(testSSP%pfconst),associated(testSSP%truncf), &
!		           associated(testSSP%ssalb), associated(testSSP%QE)
!
    CALL deallocatePointers(thisRefl=testLambPtr,thisSSP=testSSP,thisFlux=testFlux)

  RETURN

END SUBROUTINE calcLambRefl


SUBROUTINE calcReflOcean(solarang,viewang,azmang,windspeed,lut_wspeeds,phaseName,oceanLutNames,phase,reflOut)
USE interpolate_C6_LUT_m

IMPLICIT NONE
!simple driver program calculate full reflectance
REAL,INTENT(IN)::lut_wspeeds(NUM_WIND_SPEEDS)
CHARACTER(len=*),INTENT(IN)::phase,phasename
CHARACTER(len=*),DIMENSION(NUM_WIND_SPEEDS),INTENT(IN)::oceanLutNames
REAL, INTENT(IN)::solarang,viewang,azmang,windspeed
TYPE(outRefl), INTENT(INOUT)::reflOut

TYPE(pfData),SAVE::testpf
TYPE(lutRefl),DIMENSION(NUM_WIND_SPEEDS)::testRptr
type(lutSSP):: testSSP
type(lutAero)::testAero

LOGICAL, SAVE:: firstPass=.TRUE.
CHARACTER(10), SAVE::phaseSaved='JUNK'
INTEGER::nre, nwl, ntau,ierror,nu, iu


nu = size(lut_wspeeds)

IF(firstPass)THEN
  CALL nullifyPointers(thisPf = testpf)
  
  CALL pfdata_read(testpf,trim(phaseName)) 
  firstPass = .FALSE.
  phaseSaved = trim(phase)
ENDIF


!IF(trim(phaseSaved) /= trim(phase))THEN

!    phaseSaved = trim(phase)

!ENDIF

  CALL nullifyPointers(thisRefl=testRptr(1),thisSSP=testSSP,thisAero=testAero)
  DO iu = 2, nu
    CALL nullifyPointers(thisRefl=testRptr(iu))
  ENDDO
  CALL refl_read(trim(oceanLutNames(1)),solarang,viewang,azmang,ierror,thisMSR=testRptr(1),thisAero=testAero,thisSSP=testSSP)
  DO iu = 2, nu 
      CALL refl_read(trim(oceanLutNames(iu)),solarang,viewang,azmang,ierror,thisMSR=testRptr(iu))
  ENDDO     


	ntau = size(testSSP%cot); nwl = size(testSSP%ssalb,1); nre = size(testSSP%ssalb,2)
	
    IF(ASSOCIATED(reflOut%totalRefl))DEALLOCATE(reflOut%totalRefl)
	allocate(reflOut%totalRefl(ntau,nwl,nre))
	reflOut%totalReflDims = (/ntau, nwl, nre/)
	
	IF(ASSOCIATED(reflOut%lutRE))DEALLOCATE(reflOut%lutRE)
	allocate(reflOut%lutRE(nre))
	reflOut%lutRE(:) = testSSP%re
	
	IF(ASSOCIATED(reflOut%lutTau))DEALLOCATE(reflOut%lutTau)
	allocate(reflOut%lutTau(ntau))
	reflOut%lutTau(:) = testSSP%cot
	
	IF(ASSOCIATED(reflOut%lutWvl))DEALLOCATE(reflOut%lutWvl)
	allocate(reflOut%lutWvl(nwl))

	reflOut%lutWvl(:) = testSSP%wvl
	
   CALL GetReflForGivenWindSpeedNew(testpf,testSSP,testRptr,testAero,lut_wspeeds,solarang,viewang,azmang,windspeed,phase,reflOut%totalRefl,ierror)

  CALL deallocatePointers(thisRefl=testRptr(1),thisSSP=testSSP,thisAero=testAero)
  DO iu = 2, nu
    CALL deallocatePointers(thisRefl=testRptr(iu))
  ENDDO


  RETURN


END SUBROUTINE calcReflOcean




END MODULE calc_subs_m

