; NAME :    
;           getAllPhaseFunctionValues
; PURPOSE :
;           Linearly interpolate phase function related data for a given scattering angle
;    
; CALLING :
;           getAllPhaseFunctionValues, pfStruct,pFNormConst,scatAngle, interpPF, PHASE='ICE'
;           getAllPhaseFunctionValues, pfStruct,pFNormConst,scatAngle, interpPF, PHASE='LIQUID'
;           scatAngle can be a scalar or vector
;                        
; INPUTS  :
;           pfStruct = Structure containing Phase function data for Liquid and Ice phases
;           pFNormConst = Phase function normalization constants for each RE
;           scatAngle   = Scattering Angle in degrees
;           PHASE       = 'ICE' or 'LIQUID'
;           azm    = Azimuth Angle in degrees
; OUTPUT  :
;           interpPF = Array containing interpolated necessary Phase function values 
;                      for reconstruction of SS part of the reflectance
;           1st DIM = DIMS of sol, view, azm angle vector (similar dims for three angles)
;              
; HISTORY:
; Written: Nandana Amarasinghe, SSAI @ NASA/GSFC, 2017.
;


pro getAllPhaseFunctionValues, pfStruct,pFNormConst,scatAngle, interpPF, PHASE=phase
  if(phase eq 'ICE' or phase eq 'ice')then begin
    PF      = pfStruct.icePF
    scatAng = pfStruct.iceSA
  ENDIF
  if(phase eq 'LIQUID' or phase eq 'liquid')then begin
    PF      = pfStruct.liqPF
    scatAng = pfStruct.liqSA
  ENDIF
  
  
   
  
  pfsize=n_elements(scatAng)
  DIMS = size(pF,/DIMENSIONS)
  nscat=n_elements(scatAngle)
 temp = fltarr(nscat,DIMS[1],DIMS[2])
 DIM12 = DIMS[1]*DIMS[2]
 
  PF = reform(reform(PF,pfsize, DIMS[1]*DIMS[2])#diag_matrix(reform(1.0/PFNormConst,DIMS[1]*DIMS[2])),pfsize,DIMS[1],DIMS[2],/overwrite) 
  
  iL = value_locate(scatAng,scatAngle)
 
  idx=where(iL lt 0, ct)
  if(ct gt  0)then temp[idx,*,*] = PF[0,*,*];/PFNormConst[*,*]
  idx=where(iL eq pfsize-1, ct)  
  if(ct gt 0)then temp[idx,*,*] = PF[pfsize-1,*,*];/PFNormConst[*,*]
  idx = where((il ge 0) and (il lt pfsize-1), ct)
  if(ct gt 0)then begin
  temp1 = diag_matrix((scatAng[il[idx]+1]-scatAngle[idx])/(scatAng[il[idx]+1]-scatAng[il[idx]]))#reform(pF[iL[idx],*,*],ct,DIM12) $ 
          + diag_matrix((scatAngle[idx] - scatAng[il[idx]])/(scatAng[il[idx]+1]-scatAng[il[idx]]))#reform(pF[il[idx]+1,*,*],ct,DIM12)
  
  temp = reform(temp1,nscat,DIMS[1],DIMS[2])
  end
  interpPF=reform(temp)
  temp=0
  temp1=0
  end