; NAME :    
;           interpolateMSRefl_flip
; PURPOSE :
;           Linearly interpolate LUT MS reflectance for a given sun-satellite geometry
;    
; CALLING :
;           interpolateMSRefl_flip, lutstruct,sol,view,azm,interpMSR
;           sol, view, azm can be scalars or vectors of the same length
;                        
; INPUTS  :
;           lutstruct = Structure containing LUT data
; OUTPUT  :
;           interpMSR = Array containing interpolated reflectance 
;           1st DIM = DIMS of sol, view, azm angle vector (similar dims for three angles)
;              
; HISTORY:
; Written: Nandana Amarasinghe, SSAI @ NASA/GSFC, 2017.
;
 
 
 
 
  pro interpolateMSRefl_flip, lutstruct, interpMSR
  
   MSRefl     = lutstruct.MSR
  
   ipi        = lutstruct.idazm
   imi        = lutstruct.idsol
   iwi        = lutstruct.idsen
   interpMSR = interpolate(MSRefl,ipi,imi,iwi)
  
 end
